<?php

declare(strict_types=1);

namespace App\Dictionary\Medical;

/**
 * 支付类型
 */
enum OrderType: string
{
    case REG_PAY = 'RegPay';                  // 挂号支付

    case MED_PAY = 'MedPay';                  // 药费支付

    case DIAG_PAY = 'DiagPay';                // 诊间支付

    case IN_HOSP_PAY = 'InHospPay';           // 住院费支付

    case PHARMACY_PAY = 'PharmacyPay';        // 药店支付

    case INSURANCE_PAY = 'InsurancePay';      // 保险费支付

    case INT_REG_PAY = 'IntRegPay';           // 互联网医院挂号支付

    case INT_RE_DIAG_PAY = 'IntReDiagPay';    // 互联网医院复诊支付

    case INT_PSC_PAY = 'IntPscPay';           // 互联网医院处方支付

    case COVID_EXAM_PAY = 'CovidExamPay';     // 新冠检测费用

    case COVID_ANTIGEN_PAY = 'CvidAntigenPay';// 新冠抗原检测

    /**
     * Label string
     * @return string
     */
    public function label(): string
    {
        return match($this) {
            self::REG_PAY => '挂号支付',
            self::MED_PAY => '药费支付',
            self::DIAG_PAY => '诊间支付',
            self::IN_HOSP_PAY => '住院费支付',
            self::PHARMACY_PAY => '药店支付',
            self::INSURANCE_PAY => '保险费支付',
            self::INT_REG_PAY => '互联网医院挂号支付',
            self::INT_RE_DIAG_PAY => '互联网医院复诊支付',
            self::INT_PSC_PAY => '互联网医院处方支付',
            self::COVID_EXAM_PAY => '新冠检测费用',
            self::COVID_ANTIGEN_PAY => '新冠抗原检测',
        };
    }
}
