<?php
declare(strict_types = 1);

namespace App\Http\Resources\Outpatient\Record;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class RecordDetailsResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request = null): array
    {
        if (empty($this->resource)) {
            return [];
        }

        $this->resource = $this->resource['response'];

        $info = [
            'date' => date('Y-m-d', strtotime($this->resource['settlementDate'])),
            'receipt_id' => $this->resource['treaId'],
            'receipt_no' => $this->resource['hostranno'],
            'total_fee' => (float) $this->resource['costs'],
            'self_fee' => (float) $this->resource['expensePay'] ?? 0,
            'reduce_fee' => (float) $this->resource['medicalPayment'] ?? 0,
            'exec_address' => $this->resource['phyAddress'] ?: '',
            'dept_name' => $this->resource['depName'],
            'doctor_name' => $this->resource['doctName'],
            'clinic_diagnosis' => $this->resource['outpatientDiagnosis'],
            'charge_user' => $this->resource['chargeStaff'],
        ];

        foreach ($this->resource['outpatientDetail'] as $v) {
            $v = reset($v['outpatientItemreList']);
            $info['item_lists'][] = [
                'visit_date' => $v['visitdate'],
                'category_name' => $v['classname'],
                'item_name' => $v['itemname'],
                'spec' => $v['itemspec'] ?: '',
                'unit' => $v['units'],
                'quantity' => (int) $v['amount'],
                'price' => (float) $v['price'],
                'total_price' => (float) $v['costs'],

                // 冗余字段
                'package_name' => $v['ztmc'] ?: '',
                'dose_per_administration' => $v['ycjl'] ?: '',
                'dose_unit' => $v['jldw'] ?: '',
                'days_of_use' => $v['yyts'] ?: '',
                'frequency_per_day' => $v['mrcs'] ?: '',
                'dosage_schedule_name' => $v['pcmc'] ?: '',
                'medical_insurance_code' => $v['ypbm'] ?: '',
                'drug_registration_code' => $v['yjbm'] ?: '',
                'medical_insurance_category' => $v['ybfl'] ?: '',
                'employee_name' => $v['ygxm'] ?:'',
            ];
        }

        return $info;
    }
}
