<?php
declare(strict_types=1);

namespace App\Utils\Statics;

class BuildCacheKeyName
{
    /**
     * 获取 检验报告列表 缓存建名
     * @param string $open_id
     * @param string $patient_id
     * @return string
     */
    public static function getInspectReportListsKey(string $open_id, string $patient_id): string
    {
        return 'report.inspect.'. $open_id. '.'. $patient_id;
    }

    /**
     * 获取 检验报告详情图片 缓存建名
     * @param string $open_id
     * @param string $patient_id
     * @param string $serial_no
     * @return string
     */
    public static function getInspectReportDetailsImagesKey(string $open_id, string $patient_id, string $serial_no): string
    {
        return 'report.inspect.'. $open_id. '.'. $patient_id. '.images.'. $serial_no;
    }

    /**
     * 获取 门诊待缴费列表 缓存键名
     * @param string $open_id
     * @param string $patient_id
     * @return string
     */
    public static function getOutpatientPendingListsKey(string $open_id, string $patient_id): string
    {
        return 'outpatient.pending.'. $open_id. '.'. $patient_id;
    }

    /**
     * 获取 门诊待缴费详情 缓存键名
     * @param string $open_id
     * @param string $patient_id
     * @param string $serial_no
     * @return string
     */
    public static function getOutpatientPendingDetailsKey(string $open_id, string $patient_id, string $serial_no): string
    {
        return 'outpatient.pending.'. $open_id.'.'. $patient_id. '.'. $serial_no;
    }

    /**
     * 获取 门诊医保待缴费详情 缓存键名
     * @param string $open_id
     * @param string $patient_id
     * @param string $serial_no
     * @return string
     */
    public static function getOutpatientMedicalPendingDetailsKey(string $open_id, string $patient_id, string $serial_no): string
    {
        return 'outpatient.medical.pending.'. $open_id.'.'. $patient_id. '.'. $serial_no;
    }

    /**
     * 获取用户 免密授权 缓存键名
     * @param string $open_id
     * @param string $patient_id
     * @return string
     */
    public static function getUserMedicalInsuranceAuthKey(string $open_id, string $patient_id): string
    {
        return 'medical.user.info.'. $open_id.'.'. $patient_id;
    }

    /**
     * 获取挂号预结算详情缓存键名
     * @param string $open_id
     * @param string $reg_id
     * @param int $patient_property
     * @param int $settle_type
     * @return string
     */
    public static function getRegistrationPreSettleInfoKey(string $open_id, string $reg_id, int $patient_property, int $settle_type): string
    {
        return "registration.medical.pre_settle_info.{$open_id}.{$reg_id}.{$patient_property}.{$settle_type}";
    }

    /**
     * 获取缴费预结算详情缓存键名
     * @param string $open_id
     * @param string $record_id
     * @param int $settle_type 0 医保统筹 1 自费支付
     * @return string
     */
    public static function getOutpatientPrescriptionPreSettleInfoKey(string $open_id, string $record_id, int $settle_type): string
    {
        return "outpatient.medical.pre_settle_info.{$open_id}.{$record_id}.{$settle_type}";
    }
}
