<?php

declare(strict_types=1);

namespace UnifyPayment\Cores\Struct;

use InvalidArgumentException;
use UnifyPayment\Cores\Traits\Arrayable;

/**
 * Struct CreateMedicalInsuranceOrder.
 */
class CreateMedicalInsuranceOrder
{
    use Arrayable;

    /**
     * @var string
     */
    public string $orderType;

    /**
     * @var string
     */
    public string $attach;

    /**
     * @var string
     */
    public string $insuranceOrderType;

    /**
     * @var string
     */
    public string $openId;

    /**
     * @var string
     */
    public string $orderNo;

    /**
     * @var string
     */
    public string $hospitalName;

    /**
     * @var string
     */
    public string $totalAmount;

    /**
     * @var string
     */
    public string $cashAmount;

    /**
     * @var string
     */
    public string $allowFeeChange;

    /**
     * @var string
     */
    public string $spbillCreateIp;

    /**
     * @var string
     */
    public string $notifyUrl;

    /**
     * @var string
     */
    public string $title;

    /**
     * @var string
     */
    public string $returnUrl;

    /**
     * @var string
     */
    public string $payType;

    /**
     * @var string
     */
    public string $cityCode;

    /**
     * @var string
     */
    public string $consumeType;

    /**
     * @var string
     */
    public string $insuranceAmount;

    /**
     * @var string
     */
    public string $userCardType;

    /**
     * @var string
     */
    public string $idCardNo;

    /**
     * @var string
     */
    public string $name;

    /**
     * @var string
     */
    public string $serialNo;

    /**
     * @var string
     */
    public string $orgNo;

    /**
     * @var string
     */
    public string $requestContent;

    /**
     * @var string
     */
    public string $channelNo;

    /**
     * @var string
     */
    public string $billNo;

    /**
     * CreateMedicalInsuranceOrder construct.
     *
     * @param string $orderType
     * @param string $attach
     * @param string $insuranceOrderType
     * @param string $openId
     * @param string $orderNo
     * @param string $hospitalName
     * @param string $totalAmount
     * @param string $cashAmount
     * @param string $allowFeeChange
     * @param string $spbillCreateIp
     * @param string $notifyUrl
     * @param string $title
     * @param string $returnUrl
     * @param string $payType
     * @param string $cityCode
     * @param string $consumeType
     * @param string $insuranceAmount
     * @param string $userCardType
     * @param string $idCardNo
     * @param string $name
     * @param string $serialNo
     * @param string $orgNo
     * @param string $requestContent
     * @param string $channelNo
     * @param string $billNo
     */
    public function __construct(
        string $orderType = '',
        string $attach = '',
        string $insuranceOrderType = '',
        string $openId = '',
        string $orderNo = '',
        string $hospitalName = '',
        string $totalAmount = '',
        string $cashAmount = '',
        string $allowFeeChange = '',
        string $spbillCreateIp = '',
        string $notifyUrl = '',
        string $title = '',
        string $returnUrl = '',
        string $payType = '',
        string $cityCode = '',
        string $consumeType = '',
        string $insuranceAmount = '',
        string $userCardType = '',
        string $idCardNo = '',
        string $name = '',
        string $serialNo = '',
        string $orgNo = '',
        string $requestContent = '',
        string $channelNo = '',
        string $billNo = ''
    ) {
        $this->setOrderType($orderType);
        $this->setAttach($attach);
        $this->setInsuranceOrderType($insuranceOrderType);
        $this->setOpenId($openId);
        $this->setOrderNo($orderNo);
        $this->setHospitalName($hospitalName);
        $this->setTotalAmount($totalAmount);
        $this->setCashAmount($cashAmount);
        $this->setAllowFeeChange($allowFeeChange);
        $this->setSpbillCreateIp($spbillCreateIp);
        $this->setNotifyUrl($notifyUrl);
        $this->setTitle($title);
        $this->setReturnUrl($returnUrl);
        $this->setPayType($payType);
        $this->setCityCode($cityCode);
        $this->setConsumeType($consumeType);
        $this->setInsuranceAmount($insuranceAmount);
        $this->setUserCardType($userCardType);
        $this->setIdCardNo($idCardNo);
        $this->setName($name);
        $this->setSerialNo($serialNo);
        $this->setOrgNo($orgNo);
        $this->setRequestContent($requestContent);
        $this->setChannelNo($channelNo);
        $this->setBillNo($billNo);
    }

    /**
     * Get orderType value
     *
     * @return string
     */
    public function getOrderType(): string
    {
        return $this->orderType;
    }

    /**
     * Set orderType value
     *
     * @param string $orderType
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setOrderType(string $orderType = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($orderType)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orderType, true),
                    gettype($orderType)
                ), __LINE__
            );
        }

        $this->orderType = $orderType;
        return $this;
    }

    /**
     * Get attach value
     *
     * @return string
     */
    public function getAttach(): string
    {
        return $this->attach;
    }

    /**
     * Set attach value
     *
     * @param string $attach
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setAttach(string $attach = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($attach)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($attach, true),
                    gettype($attach)
                ), __LINE__
            );
        }

        $this->attach = $attach;
        return $this;
    }

    /**
     * Get insuranceOrderType value
     *
     * @return string
     */
    public function getInsuranceOrderType(): string
    {
        return $this->insuranceOrderType;
    }

    /**
     * Set insuranceOrderType value
     *
     * @param string $insuranceOrderType
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setInsuranceOrderType(string $insuranceOrderType = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($insuranceOrderType)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($insuranceOrderType, true),
                    gettype($insuranceOrderType)
                ), __LINE__
            );
        }

        $this->insuranceOrderType = $insuranceOrderType;
        return $this;
    }

    /**
     * Get openId value
     *
     * @return string
     */
    public function getOpenId(): string
    {
        return $this->openId;
    }

    /**
     * Set openId value
     *
     * @param string $openId
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setOpenId(string $openId = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($openId)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($openId, true),
                    gettype($openId)
                ), __LINE__
            );
        }

        $this->openId = $openId;
        return $this;
    }

    /**
     * Get orderNo value
     *
     * @return string
     */
    public function getOrderNo(): string
    {
        return $this->orderNo;
    }

    /**
     * Set orderNo value
     *
     * @param string $orderNo
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setOrderNo(string $orderNo = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($orderNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orderNo, true),
                    gettype($orderNo)
                ), __LINE__
            );
        }

        $this->orderNo = $orderNo;
        return $this;
    }

    /**
     * Get hospitalName value
     *
     * @return string
     */
    public function getHospitalName(): string
    {
        return $this->hospitalName;
    }

    /**
     * Set hospitalName value
     *
     * @param string $hospitalName
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setHospitalName(string $hospitalName = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($hospitalName)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($hospitalName, true),
                    gettype($hospitalName)
                ), __LINE__
            );
        }

        $this->hospitalName = $hospitalName;
        return $this;
    }

    /**
     * Get totalAmount value
     *
     * @return string
     */
    public function getTotalAmount(): string
    {
        return $this->totalAmount;
    }

    /**
     * Set totalAmount value
     *
     * @param string $totalAmount
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setTotalAmount(string $totalAmount = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($totalAmount)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($totalAmount, true),
                    gettype($totalAmount)
                ), __LINE__
            );
        }

        $this->totalAmount = $totalAmount;
        return $this;
    }

    /**
     * Get cashAmount value
     *
     * @return string
     */
    public function getCashAmount(): string
    {
        return $this->cashAmount;
    }

    /**
     * Set cashAmount value
     *
     * @param string $cashAmount
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setCashAmount(string $cashAmount = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($cashAmount)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($cashAmount, true),
                    gettype($cashAmount)
                ), __LINE__
            );
        }

        $this->cashAmount = $cashAmount;
        return $this;
    }

    /**
     * Get allowFeeChange value
     *
     * @return string
     */
    public function getAllowFeeChange(): string
    {
        return $this->allowFeeChange;
    }

    /**
     * Set allowFeeChange value
     *
     * @param string $allowFeeChange
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setAllowFeeChange(string $allowFeeChange = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($allowFeeChange)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($allowFeeChange, true),
                    gettype($allowFeeChange)
                ), __LINE__
            );
        }

        $this->allowFeeChange = $allowFeeChange;
        return $this;
    }

    /**
     * Get spbillCreateIp value
     *
     * @return string
     */
    public function getSpbillCreateIp(): string
    {
        return $this->spbillCreateIp;
    }

    /**
     * Set spbillCreateIp value
     *
     * @param string $spbillCreateIp
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setSpbillCreateIp(string $spbillCreateIp = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($spbillCreateIp)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($spbillCreateIp, true),
                    gettype($spbillCreateIp)
                ), __LINE__
            );
        }

        $this->spbillCreateIp = $spbillCreateIp;
        return $this;
    }

    /**
     * Get notifyUrl value
     *
     * @return string
     */
    public function getNotifyUrl(): string
    {
        return $this->notifyUrl;
    }

    /**
     * Set notifyUrl value
     *
     * @param string $notifyUrl
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setNotifyUrl(string $notifyUrl = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($notifyUrl)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($notifyUrl, true),
                    gettype($notifyUrl)
                ), __LINE__
            );
        }

        $this->notifyUrl = $notifyUrl;
        return $this;
    }

    /**
     * Get title value
     *
     * @return string
     */
    public function getTitle(): string
    {
        return $this->title;
    }

    /**
     * Set title value
     *
     * @param string $title
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setTitle(string $title = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($title)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($title, true),
                    gettype($title)
                ), __LINE__
            );
        }

        $this->title = $title;
        return $this;
    }

    /**
     * Get returnUrl value
     *
     * @return string
     */
    public function getReturnUrl(): string
    {
        return $this->returnUrl;
    }

    /**
     * Set returnUrl value
     *
     * @param string $returnUrl
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setReturnUrl(string $returnUrl = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($returnUrl)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($returnUrl, true),
                    gettype($returnUrl)
                ), __LINE__
            );
        }

        $this->returnUrl = $returnUrl;
        return $this;
    }

    /**
     * Get payType value
     *
     * @return string
     */
    public function getPayType(): string
    {
        return $this->payType;
    }

    /**
     * Set payType value
     *
     * @param string $payType
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setPayType(string $payType = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($payType)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($payType, true),
                    gettype($payType)
                ), __LINE__
            );
        }

        $this->payType = $payType;
        return $this;
    }

    /**
     * Get cityCode value
     *
     * @return string
     */
    public function getCityCode(): string
    {
        return $this->cityCode;
    }

    /**
     * Set cityCode value
     *
     * @param string $cityCode
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setCityCode(string $cityCode = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($cityCode)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($cityCode, true),
                    gettype($cityCode)
                ), __LINE__
            );
        }

        $this->cityCode = $cityCode;
        return $this;
    }

    /**
     * Get consumeType value
     *
     * @return string
     */
    public function getConsumeType(): string
    {
        return $this->consumeType;
    }

    /**
     * Set consumeType value
     *
     * @param string $consumeType
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setConsumeType(string $consumeType = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($consumeType)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($consumeType, true),
                    gettype($consumeType)
                ), __LINE__
            );
        }

        $this->consumeType = $consumeType;
        return $this;
    }

    /**
     * Get insuranceAmount value
     *
     * @return string
     */
    public function getInsuranceAmount(): string
    {
        return $this->insuranceAmount;
    }

    /**
     * Set insuranceAmount value
     *
     * @param string $insuranceAmount
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setInsuranceAmount(string $insuranceAmount = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($insuranceAmount)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($insuranceAmount, true),
                    gettype($insuranceAmount)
                ), __LINE__
            );
        }

        $this->insuranceAmount = $insuranceAmount;
        return $this;
    }

    /**
     * Get userCardType value
     *
     * @return string
     */
    public function getUserCardType(): string
    {
        return $this->userCardType;
    }

    /**
     * Set userCardType value
     *
     * @param string $userCardType
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setUserCardType(string $userCardType = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($userCardType)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($userCardType, true),
                    gettype($userCardType)
                ), __LINE__
            );
        }

        $this->userCardType = $userCardType;
        return $this;
    }

    /**
     * Get idCardNo value
     *
     * @return string
     */
    public function getIdCardNo(): string
    {
        return $this->idCardNo;
    }

    /**
     * Set idCardNo value
     *
     * @param string $idCardNo
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setIdCardNo(string $idCardNo = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($idCardNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($idCardNo, true),
                    gettype($idCardNo)
                ), __LINE__
            );
        }

        $this->idCardNo = $idCardNo;
        return $this;
    }

    /**
     * Get name value
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * Set name value
     *
     * @param string $name
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setName(string $name = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($name)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($name, true),
                    gettype($name)
                ), __LINE__
            );
        }

        $this->name = $name;
        return $this;
    }

    /**
     * Get serialNo value
     *
     * @return string
     */
    public function getSerialNo(): string
    {
        return $this->serialNo;
    }

    /**
     * Set serialNo value
     *
     * @param string $serialNo
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setSerialNo(string $serialNo = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($serialNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($serialNo, true),
                    gettype($serialNo)
                ), __LINE__
            );
        }

        $this->serialNo = $serialNo;
        return $this;
    }

    /**
     * Get orgNo value
     *
     * @return string
     */
    public function getOrgNo(): string
    {
        return $this->orgNo;
    }

    /**
     * Set orgNo value
     *
     * @param string $orgNo
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setOrgNo(string $orgNo = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($orgNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($orgNo, true),
                    gettype($orgNo)
                ), __LINE__
            );
        }

        $this->orgNo = $orgNo;
        return $this;
    }

    /**
     * Get requestContent value
     *
     * @return string
     */
    public function getRequestContent(): string
    {
        return $this->requestContent;
    }

    /**
     * Set requestContent value
     *
     * @param string $requestContent
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setRequestContent(string $requestContent = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($requestContent)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($requestContent, true),
                    gettype($requestContent)
                ), __LINE__
            );
        }

        $this->requestContent = $requestContent;
        return $this;
    }

    /**
     * Get channelNo value
     *
     * @return string
     */
    public function getChannelNo(): string
    {
        return $this->channelNo;
    }

    /**
     * Set channelNo value
     *
     * @param string $channelNo
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setChannelNo(string $channelNo = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($channelNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($channelNo, true),
                    gettype($channelNo)
                ), __LINE__
            );
        }

        $this->channelNo = $channelNo;
        return $this;
    }

    /**
     * Get billNo value
     *
     * @return string
     */
    public function getBillNo(): string
    {
        return $this->billNo;
    }

    /**
     * Set billNo value
     *
     * @param string $billNo
     *
     * @return CreateMedicalInsuranceOrder
     */
    public function setBillNo(string $billNo = ''): CreateMedicalInsuranceOrder
    {
        // validation for constraint: string
        if (!is_string($billNo)) {
            throw new InvalidArgumentException(
                sprintf(
                    'Invalid value %s, please provide a string, %s given',
                    var_export($billNo, true),
                    gettype($billNo)
                ), __LINE__
            );
        }

        $this->billNo = $billNo;
        return $this;
    }
}
