<?php

declare(strict_types=1);

namespace UnifyPayment\Modules\Pay;

use ReflectionException;
use UnifyPayment\Cores\BasicClient;
use UnifyPayment\Cores\Exceptions\InvalidConfigException;
use UnifyPayment\Cores\Exceptions\RuntimeException;
use UnifyPayment\Cores\Struct\CreateMedicalInsuranceOrder;
use UnifyPayment\Cores\Struct\CreateOrder;

class MiniProgramClient extends BasicClient
{

    /**
     * WeChat Mini Program Payment
     *
     * @param CreateOrder $order
     *
     * @return array|string
     *
     * @throws ReflectionException
     * @throws InvalidConfigException
     * @throws RuntimeException
     */
    public function jsapi(CreateOrder $order): array|string
    {
        $this->payload = array_merge($this->payload, $order->toArray());
        $this->payload['sign'] = $this->generateSign($this->payload);

        return $this->request('post', '/index.php/api/pay/miniapp');
    }

    /**
     * WeChat Mini Program Medical Insurance Payment
     *
     * @param CreateMedicalInsuranceOrder $order
     *
     * @return array|string
     *
     * @throws InvalidConfigException
     * @throws ReflectionException
     * @throws RuntimeException
     */
    public function medicalPay(CreateMedicalInsuranceOrder $order): array|string
    {
        $this->payload = array_merge($this->payload, $order->toArray());
        $this->payload['sign'] = $this->generateSign($this->payload);

        return $this->request('post', '/index.php/api/pay/mpInsurance');
    }
}
